#!/bin/sh
# @(#) $Id: acld.sh 621 2009-10-10 06:41:05Z leres $ (LBL)

#
# PROVIDE: acld
#

prog="`basename $0`"
export PATH="/usr/local/sbin:${PATH}"

pidfile=/var/run/acld.pid
dir="/usr/operator/acl2"

start() {
	if [ -r ${pidfile} ]; then
		pid="`cat ${pidfile}`"
		if [ -n "${pidfile}" ]; then
			kill -0 ${pid} 2> /dev/null
			if [ $? -eq 0 ]; then
				echo "${prog}: acld already running (pid ${pid})" 1>&2
				exit 1
			fi
		fi
	fi

	echo -n " acld"

	cd ${dir} || exit 1

	sub="acld on `hostname` restarted"
	(while : ; do
		myuser="${acld_user:-zeek}"

		rm -f ${pidfile}
		(umask 022 ; touch ${pidfile})
		chown ${myuser}:wheel ${pidfile}

		debuglog="logs/acld.log"
		if [ ! -f "${debuglog}" ]; then
			(umask 027 ; touch ${debuglog})
		fi
		chown ${myuser}:wheel ${debuglog}

		su -fm ${myuser} <<EOF
		acld -f -d -o ${debuglog}
EOF
		xstatus=$?
		if [ "${xstatus}" -gt 128 ]; then
			sig="`expr ${xstatus} - 128`"
			if [ "${sig}" -eq 15 ]; then
				# SIGTERM -- just exit
				exit 0
			fi
			msg="[Exited via signal ${sig}]"
		else
			msg="[After exiting with status ${xstatus}]"
		fi
		sleep 10

		# Do this every time in case it changes
		. /etc/rc.conf
		notify="${acld_watcher:-root}"

		(echo "To: ${notify}"
		echo "Subject: ${sub}"
		echo ""
		echo "${msg}"
		echo ""
		tail -33 ${f}) | sendmail -bm -froot -t

	done &) > /dev/null 2>&1
}

stop() {
	if [ -s ${pidfile} ]; then
		pid="`cat ${pidfile}`"
		kill -TERM "${pid}"
		didany=0
		while true; do
			kill -0 ${pid} 2> /dev/null
			if [ $? -ne 0 ]; then
				break
			fi
			sleep 1
			if [ ${didany} -eq 0 ]; then
				echo -n "Waiting for"
			fi
			didany=1
			echo -n " ${pid}"
		done
		if [ ${didany} -ne 0 ]; then
			echo " done"
		fi
	fi
	rm -f ${pidfile}
}

status() {
	f="${dir}/scripts/acl.exp"
	if [ ! -r ${f} ]; then
		echo "$0: Can't find ${f}" 1>&2
		exit 1
	fi
	if [ -s ${pidfile} ]; then
		pgrep -F ${pidfile} acld > /dev/null
		if [ $? -ne 0 ]; then
			echo "$0: acld not running" 1>&2
			exit 1
		fi
	else
		echo "$0: Warning: pid file missing (${pidfile})" 1>&2
	fi
	${f} state
}

. /etc/rc.conf

if [ -z "${acld_enable}" -o "x${acld_enable}" != "xYES" -o ! -d ${dir} ] ; then
	exit
fi

case "$1" in

'start')
	start
	;;

'stop')
	stop
        ;;

'restart')
	stop
	sleep 1
	start
	echo ''
	;;

'status')
	status
	;;

*)
	echo "Usage: $0 { start | stop | restart | status }" 1>&2
	exit 1
	;;
esac
